==> owncloud-10.0.7.tgz: owncloud/lib/l10n/ar.js <==
OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "الكتابة في مجلد \"config\" غير ممكنة!",
    "This can usually be fixed by giving the webserver write access to the config directory" : "يمكن حل هذا عادة بإعطاء خادم الوب صلاحية الكتابة في مجلد config",
    "See %s" : "أنظر %s",
    "Sample configuration detected" : "تم اكتشاف إعدادات عيّنة",
    "PHP %s or higher is required." : "إصدار PHP %s أو أحدث منه مطلوب.",
    "PHP with a version lower than %s is required." : "PHP الإصدار %s أو أقل مطلوب.",
    "%sbit or higher PHP required." : "مكتبات PHP ذات %s بت أو أعلى مطلوبة.",
    "Following databases are supported: %s" : "قواعد البيانات التالية مدعومة: %s",
    "The command line tool %s could not be found" : "لم يتم العثور على أداة سطر الأوامر %s",
    "The library %s is not available." : "مكتبة %s غير متوفرة.",
    "Unknown filetype" : "نوع الملف غير معروف",
    "Invalid image" : "الصورة غير صالحة",
    "today" : "اليوم",
    "yesterday" : "يوم أمس",
    "_%n day ago_::_%n days ago_" : ["قبل ساعات","قبل يوم","قبل يومين","قبل %n يوماً","قبل %n يوماً","قبل %n يوماً"],
    "last month" : "الشهر الماضي",
    "_%n month ago_::_%n months ago_" : ["قبل عدة أيام","قبل شهر","قبل شهرين","قبل %n شهراً","قبل %n شهراً","قبل %n شهراً"],
    "last year" : "السنةالماضية",
    "seconds ago" : "منذ ثواني",
    "None" : "لا شيء",
    "Username" : "إسم المستخدم",
    "Password" : "كلمة السر",
    "Empty filename is not allowed" : "لا يسمح بأسماء فارغة للملفات",
    "4-byte characters are not supported in file names" : "المحارف ذات 4 بايت غير مسموح بها في أسماء الملفات",
    "File name is a reserved word" : "اسم الملف كلمة محجوزة",
    "File name contains at least one invalid character" : "اسم الملف به ، على الأقل ، حرف غير صالح",
    "File name is too long" : "اسم الملف طويل جداً",
    "App directory already exists" : "مجلد التطبيق موجود مسبقا",
    "Can't create app folder. Please fix permissions. %s" : "لا يمكن إنشاء مجلد التطبيق. يرجى تعديل الصلاحيات. %s",
    "Archive does not contain a directory named %s" : "الأرشيف لا يحتوي مجلداً اسمه %s",
    "No source specified when installing app" : "لم يتم تحديد المصدر عن تثبيت البرنامج",
    "No href specified when installing app from http" : "لم يتم تحديد href عند تثبيت التطبيق من http",
    "No path specified when installing app from local file" : "لم يتم تحديد مسار عند تثبيت التطبيق من ملف محلّي",
    "Archives of type %s are not supported" : "الأرشيفات من نوع  %s غير مدعومة",
    "Failed to open archive when installing app" : "فشل فتح الأرشيف أثناء تثبيت التطبيق",
    "App does not provide an info.xml file" : "التطبيق لا يتوفر على ملف info.xml",
    "App cannot be installed because appinfo file cannot be read." : "لا يمكن تثبيت التطبيق لأن ملف appinfo غير ممكنة قراءته.",
    "Signature could not get checked. Please contact the app developer and check your admin screen." : "لم يتم التحقق من التوقيع.  فضلاً اتصل بمطوّر التطبيق و تحقق من شاشة الإدارة في حسابك.",
    "App can't be installed because of not allowed code in the App" : "لم يتم تثبيت التطبيق لوجود شفرة غير مسموح بها في التطبيق",
    "App can't be installed because it is not compatible with this version of ownCloud" : "لم يتم تثبيت التطبيق لأنه غير متوافق مع هذا الإصدار من ownCloud",
    "App can't be installed because it contains the <shipped>true</shipped> tag which is not allowed for non shipped apps" : "لم يتم تثبيت التطبيق لأن به علامة <shipped>true</shipped> التي لايسمح بها في التطبيقات غير المشحونة",
    "App can't be installed because the version in info.xml is not the same as the version reported from the app store" : "لم يتم تثبيت التطبيق لأن الإصدار في info.xml مختلف عن الإصدار المذكور في متجر التطبيقات",
    "Apps" : "التطبيقات",
    "General" : "عام",
    "Storage" : "وحدة التخزين",
    "Security" : "الأمان",
    "Encryption" : "التشفير",
    "Sharing" : "مشاركة",
    "Search" : "البحث",
    "%s enter the database username and name." : "%s أدخِل اسم قاعدة البيانات واسم مستخدمها.",
    "%s enter the database username." : "%s ادخل اسم المستخدم الخاص بقاعدة البيانات.",
    "%s enter the database name." : "%s ادخل اسم فاعدة البيانات",
    "%s you may not use dots in the database name" : "%s لا يسمح لك باستخدام نقطه (.) في اسم قاعدة البيانات",
    "Oracle connection could not be established" : "لم تنجح محاولة اتصال Oracle",
    "Oracle username and/or password not valid" : "اسم المستخدم  و/أو  كلمة المرور لنظام Oracle غير صحيح",
    "DB Error: \"%s\"" : "خطأ في قواعد البيانات : \"%s\"",
    "Offending command was: \"%s\"" : "الأمر المخالف كان : \"%s\"",
    "You need to enter either an existing account or the administrator." : "انت بحاجة لكتابة اسم مستخدم موجود أو حساب المدير.",
    "Offending command was: \"%s\", name: %s, password: %s" : "الأمر المخالف كان : \"%s\", اسم المستخدم : %s, كلمة المرور: %s",
    "PostgreSQL username and/or password not valid" : "اسم المستخدم / أو كلمة المرور الخاصة بـPostgreSQL غير صحيحة",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "نظام ماك الإصدار X غير مدعوم و %s لن يعمل بشكل صحيح على هذه المنصة.  استخدمه على مسؤوليتك!",
    "For the best results, please consider using a GNU/Linux server instead." : "فضلاً ضع في الاعتبار استخدام نظام GNU/Linux بدل الأنظمة الأخرى للحصول على أفضل النتائج.",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "فضلاً إحذف إعداد open_basedir من ملف php.ini لديك أو حوّل إلى PHP إصدار 64 بت.",
    "Set an admin username." : "اعداد اسم مستخدم للمدير",
    "Set an admin password." : "اعداد كلمة مرور للمدير",
    "Can't create or write into the data directory %s" : "لا يمكن الإنشاء أو الكتابة في مجلد البيانات %s",
    "Invalid Federated Cloud ID" : "معرّف سحابة الاتحاد غير صالح",
    "%s shared »%s« with you" : "%s شارك »%s« معك",
    "%s via %s" : "%s عبر %s",
    "Sharing %s failed, because the file does not exist" : "فشلت مشاركة %s فالملف غير موجود",
    "You are not allowed to share %s" : "أنت غير مسموح لك أن تشارك %s",
    "Sharing %s failed, because you can not share with yourself" : "فشلت مشاركة %s لأنك لايمكنك المشاركة مع نفسك",
    "Sharing %s failed, because the user %s does not exist" : "فشلت مشاركة %s لأن المستخدم %s غير موجود",
    "Share type %s is not valid for %s" : "مشاركة النوع %s غير صالحة لـ %s",
    "Could not find category \"%s\"" : "تعذر العثور على المجلد \"%s\"",
    "A valid username must be provided" : "يجب ادخال اسم مستخدم صحيح",
    "A valid password must be provided" : "يجب ادخال كلمة مرور صحيحة",
    "Help" : "المساعدة",
    "Settings" : "الإعدادات",
    "Users" : "المستخدمين",
    "web services under your control" : "خدمات الشبكة تحت سيطرتك",
    "Application is not enabled" : "التطبيق غير مفعّل",
    "Authentication error" : "لم يتم التأكد من الشخصية بنجاح",
    "Token expired. Please reload page." : "انتهت صلاحية الكلمة , يرجى اعادة تحميل الصفحة",
    "Unknown user" : "المستخدم غير معروف",
    "Storage is temporarily not available" : "وحدة التخزين غير متوفرة مؤقتاً"
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");

==> owncloud-10.0.10.tgz: owncloud/lib/l10n/ar.js <==
OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "الكتابة في مجلد \"config\" غير ممكنة!",
    "This can usually be fixed by giving the webserver write access to the config directory" : "يمكن حل هذا عادة بإعطاء خادم الوب صلاحية الكتابة في مجلد config",
    "See %s" : "أنظر %s",
    "Sample configuration detected" : "تم اكتشاف إعدادات عيّنة",
    "PHP %s or higher is required." : "إصدار PHP %s أو أحدث منه مطلوب.",
    "PHP with a version lower than %s is required." : "PHP الإصدار %s أو أقل مطلوب.",
    "%sbit or higher PHP required." : "مكتبات PHP ذات %s بت أو أعلى مطلوبة.",
    "Following databases are supported: %s" : "قواعد البيانات التالية مدعومة: %s",
    "The command line tool %s could not be found" : "لم يتم العثور على أداة سطر الأوامر %s",
    "The library %s is not available." : "مكتبة %s غير متوفرة.",
    "Unknown filetype" : "نوع الملف غير معروف",
    "Invalid image" : "الصورة غير صالحة",
    "today" : "اليوم",
    "yesterday" : "يوم أمس",
    "_%n day ago_::_%n days ago_" : ["قبل ساعات","قبل يوم","قبل يومين","قبل %n يوماً","قبل %n يوماً","قبل %n يوماً"],
    "last month" : "الشهر الماضي",
    "_%n month ago_::_%n months ago_" : ["قبل عدة أيام","قبل شهر","قبل شهرين","قبل %n شهراً","قبل %n شهراً","قبل %n شهراً"],
    "last year" : "السنةالماضية",
    "seconds ago" : "منذ ثواني",
    "None" : "لا شيء",
    "Username" : "إسم المستخدم",
    "Password" : "كلمة السر",
    "Empty filename is not allowed" : "لا يسمح بأسماء فارغة للملفات",
    "4-byte characters are not supported in file names" : "المحارف ذات 4 بايت غير مسموح بها في أسماء الملفات",
    "File name is a reserved word" : "اسم الملف كلمة محجوزة",
    "File name contains at least one invalid character" : "اسم الملف به ، على الأقل ، حرف غير صالح",
    "File name is too long" : "اسم الملف طويل جداً",
    "App directory already exists" : "مجلد التطبيق موجود مسبقا",
    "Can't create app folder. Please fix permissions. %s" : "لا يمكن إنشاء مجلد التطبيق. يرجى تعديل الصلاحيات. %s",
    "Archive does not contain a directory named %s" : "الأرشيف لا يحتوي مجلداً اسمه %s",
    "No source specified when installing app" : "لم يتم تحديد المصدر عن تثبيت البرنامج",
    "No href specified when installing app from http" : "لم يتم تحديد href عند تثبيت التطبيق من http",
    "No path specified when installing app from local file" : "لم يتم تحديد مسار عند تثبيت التطبيق من ملف محلّي",
    "Archives of type %s are not supported" : "الأرشيفات من نوع  %s غير مدعومة",
    "Failed to open archive when installing app" : "فشل فتح الأرشيف أثناء تثبيت التطبيق",
    "App does not provide an info.xml file" : "التطبيق لا يتوفر على ملف info.xml",
    "App cannot be installed because appinfo file cannot be read." : "لا يمكن تثبيت التطبيق لأن ملف appinfo غير ممكنة قراءته.",
    "Signature could not get checked. Please contact the app developer and check your admin screen." : "لم يتم التحقق من التوقيع.  فضلاً اتصل بمطوّر التطبيق و تحقق من شاشة الإدارة في حسابك.",
    "App can't be installed because of not allowed code in the App" : "لم يتم تثبيت التطبيق لوجود شفرة غير مسموح بها في التطبيق",
    "App can't be installed because it is not compatible with this version of ownCloud" : "لم يتم تثبيت التطبيق لأنه غير متوافق مع هذا الإصدار من ownCloud",
    "App can't be installed because it contains the <shipped>true</shipped> tag which is not allowed for non shipped apps" : "لم يتم تثبيت التطبيق لأن به علامة <shipped>true</shipped> التي لايسمح بها في التطبيقات غير المشحونة",
    "App can't be installed because the version in info.xml is not the same as the version reported from the app store" : "لم يتم تثبيت التطبيق لأن الإصدار في info.xml مختلف عن الإصدار المذكور في متجر التطبيقات",
    "Apps" : "التطبيقات",
    "General" : "عام",
    "Storage" : "وحدة التخزين",
    "Security" : "الأمان",
    "Encryption" : "التشفير",
    "Sharing" : "مشاركة",
    "Search" : "البحث",
    "%s enter the database username and name." : "%s أدخِل اسم قاعدة البيانات واسم مستخدمها.",
    "%s enter the database username." : "%s ادخل اسم المستخدم الخاص بقاعدة البيانات.",
    "%s enter the database name." : "%s ادخل اسم فاعدة البيانات",
    "%s you may not use dots in the database name" : "%s لا يسمح لك باستخدام نقطه (.) في اسم قاعدة البيانات",
    "Oracle connection could not be established" : "لم تنجح محاولة اتصال Oracle",
    "Oracle username and/or password not valid" : "اسم المستخدم  و/أو  كلمة المرور لنظام Oracle غير صحيح",
    "DB Error: \"%s\"" : "خطأ في قواعد البيانات : \"%s\"",
    "Offending command was: \"%s\"" : "الأمر المخالف كان : \"%s\"",
    "You need to enter either an existing account or the administrator." : "انت بحاجة لكتابة اسم مستخدم موجود أو حساب المدير.",
    "Offending command was: \"%s\", name: %s, password: %s" : "الأمر المخالف كان : \"%s\", اسم المستخدم : %s, كلمة المرور: %s",
    "PostgreSQL username and/or password not valid" : "اسم المستخدم / أو كلمة المرور الخاصة بـPostgreSQL غير صحيحة",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "نظام ماك الإصدار X غير مدعوم و %s لن يعمل بشكل صحيح على هذه المنصة.  استخدمه على مسؤوليتك!",
    "For the best results, please consider using a GNU/Linux server instead." : "فضلاً ضع في الاعتبار استخدام نظام GNU/Linux بدل الأنظمة الأخرى للحصول على أفضل النتائج.",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "فضلاً إحذف إعداد open_basedir من ملف php.ini لديك أو حوّل إلى PHP إصدار 64 بت.",
    "Set an admin username." : "اعداد اسم مستخدم للمدير",
    "Set an admin password." : "اعداد كلمة مرور للمدير",
    "Can't create or write into the data directory %s" : "لا يمكن الإنشاء أو الكتابة في مجلد البيانات %s",
    "Invalid Federated Cloud ID" : "معرّف سحابة الاتحاد غير صالح",
    "%s shared »%s« with you" : "%s شارك »%s« معك",
    "%s via %s" : "%s عبر %s",
    "Sharing %s failed, because the file does not exist" : "فشلت مشاركة %s فالملف غير موجود",
    "You are not allowed to share %s" : "أنت غير مسموح لك أن تشارك %s",
    "Sharing %s failed, because you can not share with yourself" : "فشلت مشاركة %s لأنك لايمكنك المشاركة مع نفسك",
    "Sharing %s failed, because the user %s does not exist" : "فشلت مشاركة %s لأن المستخدم %s غير موجود",
    "Share type %s is not valid for %s" : "مشاركة النوع %s غير صالحة لـ %s",
    "Could not find category \"%s\"" : "تعذر العثور على المجلد \"%s\"",
    "A valid username must be provided" : "يجب ادخال اسم مستخدم صحيح",
    "A valid password must be provided" : "يجب ادخال كلمة مرور صحيحة",
    "Help" : "المساعدة",
    "Settings" : "الإعدادات",
    "Users" : "المستخدمين",
    "web services under your control" : "خدمات الشبكة تحت سيطرتك",
    "Application is not enabled" : "التطبيق غير مفعّل",
    "Authentication error" : "لم يتم التأكد من الشخصية بنجاح",
    "Token expired. Please reload page." : "انتهت صلاحية الكلمة , يرجى اعادة تحميل الصفحة",
    "Unknown user" : "المستخدم غير معروف",
    "Storage is temporarily not available" : "وحدة التخزين غير متوفرة مؤقتاً",
    "Imprint" : "الدمغة.",
    "__language_name__" : "__language_name__"
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
